/* CSS for Customizer Custom Controls */

.popularfx-edit-link{
display: block;
border:1px solid #ccc;
border-bottom:0px solid #ccc;
padding: 8px;
font-size: 14px;
font-weight: 600;
font-style: normal;
text-decoration: none;
background: #fff;
}

.popularfx-edit-link:last-of-type{
margin-bottom: 30px;
border-bottom:1px solid #ccc;
}

.popularfx-edit-link:hover{
background: #efefef;
}

/* Standard Selection */

#customize-control-popularfx_sidebar_default{
border-bottom: 1px double #ccc;
padding-bottom: 15px;
}

#accordion-section-popularfx_pro_link,
#accordion-section-no_pagelayer {
background: #fff;
font-size: 13px;
font-weight: 600;
text-align: right;
}

#accordion-section-no_pagelayer{
background: #FF0000;
}

#accordion-section-popularfx_pro_link a,
#accordion-section-no_pagelayer a{
padding:10px;
display: block;
text-decoration: none;
text-align: left;
}

#accordion-section-no_pagelayer a{
color: #FFEDD3;
}

#accordion-section-popularfx_pro_link a span,
#accordion-section-no_pagelayer a span{
padding-right: 5px;
}

.popularfx-customize-description {
width:100%;
float: left;
}

/* Alpha Color Picker  */
.customize-control-alpha-color .wp-picker-container .iris-picker {
border-bottom:none;
}

.customize-control-alpha-color .wp-picker-container {
max-width: 257px;
}

.customize-control-alpha-color .wp-picker-open + .wp-picker-input-wrap {
width: 100%;
}

.customize-control-alpha-color .wp-picker-input-wrap input[type="text"].wp-color-picker.alpha-color-control {
float: left;
width: 195px;
}

.customize-control-alpha-color .wp-picker-input-wrap .button {
margin-left: 0;
float: right;
}

.wp-picker-container .wp-picker-open ~ .wp-picker-holder .alpha-color-picker-container {
display: block;
}

.alpha-color-picker-container {
border: 1px solid #dfdfdf;
border-top: none;
display: none;
background-color: #fff;
padding: 0 11px 10px;
position: relative;
}

.alpha-color-picker-container .ui-widget-content,
.alpha-color-picker-container .ui-widget-header,
.alpha-color-picker-wrap .ui-state-focus {
background: transparent;
border: none;
}

.alpha-color-picker-wrap a.iris-square-value:focus {
-webkit-box-shadow: none;
box-shadow: none;
}

.alpha-color-picker-container .ui-slider {
position: relative;
z-index: 1;
height: 24px;
text-align: center;
margin: 0 auto;
width: 88%;
width: calc( 100% - 28px );
}

.alpha-color-picker-container .ui-slider-handle,
.alpha-color-picker-container .ui-widget-content .ui-state-default {
color: #777;
background-color: #fff;
text-shadow: 0 1px 0 #fff;
text-decoration: none;
position: absolute;
z-index: 2;
box-shadow: 0 1px 2px rgba(0,0,0,0.2);
border: 1px solid #aaa;
-webkit-border-radius: 4px;
-moz-border-radius: 4px;
border-radius: 4px;
margin-top: -2px;
top: 0;
height: 26px;
width: 26px;
cursor: ew-resize;
font-size: 0;
padding: 0;
line-height: 27px;
margin-left: -14px;
}

.alpha-color-picker-container .ui-slider-handle.show-opacity {
font-size: 12px;
}

.alpha-color-picker-container .click-zone {
width: 14px;
height: 24px;
display: block;
position: absolute;
left: 10px;
}

.alpha-color-picker-container .max-click-zone {
right: 10px;
left: auto;
}

.alpha-color-picker-container .transparency {
height: 24px;
width: 100%;
background-color: #fff;
background-image: url(./images/color-picker-transparency-grid.png);
box-shadow: 0 0 5px rgba(0,0,0,0.4) inset;
-webkit-border-radius: 3px;
-moz-border-radius: 3px;
border-radius: 3px;
padding: 0;
margin-top: -24px;
}

@media only screen and (max-width: 782px) {
.customize-control-alpha-color .wp-picker-input-wrap input[type="text"].wp-color-picker.alpha-color-control {
	width: 184px;
}
}

@media only screen and (max-width: 640px) {
.customize-control-alpha-color .wp-picker-input-wrap input[type="text"].wp-color-picker.alpha-color-control {
	width: 172px;
	height: 33px;
}
}

/* Alpha Color Picker & Standard Color Picker */
.customize-control-color .wp-color-result,
.customize-control-alpha-color .wp-color-result {
box-shadow: none;
}

.customize-control-color .wp-color-result .wp-color-result-text,
.customize-control-alpha-color .wp-color-result .wp-color-result-text {
border-left: none;
}

.wp-picker-holder .iris-picker .iris-palette {
box-shadow: none;
}

.wp-picker-container .iris-picker,
.wp-picker-container .alpha-color-picker-container {
border-radius: 0;
border: none;
}

.wp-picker-container .alpha-color-picker-container {
width: 233px;
}

/* WPColorPicker Alpha Color Picker */
.customize-control-wpcolorpicker-alpha-color .wp-color-result {
box-shadow: none;
}

.customize-control-wpcolorpicker-alpha-color .wp-picker-input-wrap input[type="text"].wp-color-picker {
float: left;
width: 195px;
}

.customize-control-wpcolorpicker-alpha-color .wp-color-result .wp-color-result-text {
border-left: none;
}

/* Custom checkbox style start */
#customize-control-pfx_enable_scrolltop input[type="checkbox"]{
float: right;
font-size: 12px;
margin: 0px;
-webkit-appearance: none;
-moz-appearance: none;
appearance: none;
width: 3.5em;
height: 1.7em;
background: #ddd;
border-radius: 3em;
position: relative;
cursor: pointer;
outline: none;
-webkit-transition: all .2s ease-in-out;
transition: all .2s ease-in-out;
}

#customize-control-pfx_enable_scrolltop .customize-inside-control-row{
margin-left: 0px !important;
text-transform: capitalize;
}

#customize-control-pfx_enable_scrolltop input[type="checkbox"]:checked{
background-color: #1A9CDB;
border-color: #1A9CDB;
}

#customize-control-pfx_enable_scrolltop input[type="checkbox"]:after{
position: absolute;
content: "";
width: 1.5em;
height: 1.5em;
border-radius: 50%;
background: #fff;
-webkit-box-shadow: 0 0 .25em rgba(0,0,0,.3);
box-shadow: 0 0 .25em rgba(0,0,0,.3);
-webkit-transform: scale(.7);
transform: scale(.7);
left: 0;
-webkit-transition: all .2s ease-in-out;
transition: all .2s ease-in-out;
}

#customize-control-pfx_enable_scrolltop input[type="checkbox"]:checked:before{
display: none;
}

#customize-control-pfx_enable_scrolltop input[type="checkbox"]:checked:after{
left: calc(100% - 1.5em);
}
/* Custom checkbox style end*/
